Installing csdmpy package — csdmpy 0.1.1 documentation

# Installing csdmpy package

We recommend installing anaconda distribution for python version 3.6 or higher. The anaconda distribution ships with numerous packages and modules including Numpy, Scipy, and Matplotlib which are useful packages for handling scientific datasets.

Using PIP:

PIP is a package manager for Python packages and is included with python version 3.4 and higher.:

    $ pip install csdmpy